
Force setting of frequency after startup, as the "guessing" of frequencies 
in the ACPI cpufreq driver might be wrong. It is really unfortunate that the
ACPI specification does not provide us with a "get current P state" method.

This patch is needed by a platform that supports ACPI based cpufreq,
but boots up with lowest possible freq. Without this patch, ACPI cpufreq
assumes that the processors are running at the highest freq.

Signed-off-by: Dominik Brodowski <linux@dominikbrodowski.net>
Signed-off-by: Venkatesh Pallipadi <venkatesh.pallipadi@intel.com>

Index: to-linus/arch/i386/kernel/cpu/cpufreq/acpi-cpufreq.c
===================================================================
--- to-linus.orig/arch/i386/kernel/cpu/cpufreq/acpi-cpufreq.c
+++ to-linus/arch/i386/kernel/cpu/cpufreq/acpi-cpufreq.c
@@ -442,6 +442,13 @@ acpi_cpufreq_cpu_init (
 			(u32) data->acpi_data.states[i].transition_latency);
 
 	cpufreq_frequency_table_get_attr(data->freq_table, policy->cpu);
+	
+	/*
+	 * the first call to ->target() should result in us actually
+	 * writing something to the appropriate registers.
+	 */
+	data->resume = 1;
+	
 	return (result);
 
  err_freqfree:
